@@ -41,10 +41,7 @@ class YoloHub:
         self.model = model
         return model
 
-    def prediction(self, image, yaml_file=None):
-        return self.model.predict(image, yaml_file=yaml_file)
-
-    def view_model(self, file_format="pdf"):
+    def view_model_architecture(self, file_format: str = "pdf"):
         try:
             from torchview import draw_graph
         except:
@@ -61,14 +58,15 @@ class YoloHub:
 
         model_graph = draw_graph(
             model_arch,
-            input_size=(1, 3, 352, 352),
+            input_size=(1, 3, 384, 640),
             expand_nested=True,
             depth=3,
         )
-        
+
         model_graph.visual_graph.render(format=file_format)
         return model_graph
+
+
 if __name__ == "__main__":
-    model = YoloHub(model_type="yolov6", model_path="yolov6n.pt", device="cuda:0", image_size=640)
-    image = "data/highway.jpg"
-    result = model.view_model(is_pdf=False, is_svg=True)
+    model = YoloHub(model_type="yolov5", model_path="yolov5n.pt", device="cuda:0", image_size=640)
+    result = model.view_model_architecture(file_format="pdf")
